import matplotlib.pyplot as plt
import numpy as np
import astropy.units as u
from shocksgo import power_spectrum

from shocksgo import generate_solar_fluxes

times, fluxes, kernel = generate_solar_fluxes(duration=100*u.day, cadence=60*u.s)

freq, power = power_spectrum(fluxes, d=60)

plt.semilogy(freq * 1e6, power, ',', label='Samples')
plt.semilogy(freq * 1e6, 1e6 * kernel.get_psd(2*np.pi*freq)/(2*np.pi), alpha=0.7, label='Kernel')
plt.ylim([1e-5, 1e-1])
plt.xlim([2000, 4000])
plt.gca().set(xlabel='Frequency [$\mu$Hz]', ylabel='Power [ppm$^2$/$\mu$Hz]')
plt.show()