import numpy as np
import matplotlib.pyplot as plt
import astropy.units as u
from astropy.constants import R_sun, M_sun, L_sun

from shocksgo import generate_stellar_fluxes

M = 1*M_sun
L = 1*L_sun
T_eff = 5777 * u.K
R = 1*R_sun

freqs = np.linspace(2000, 4000, 10)
log_amps = np.exp(-0.5 * (freqs - 3000)**2 / 1000**2) - 32
log_lifetimes = np.ones_like(freqs) * 7
duration = 2 * u.min

times, fluxes, kernel = generate_stellar_fluxes(duration, M, T_eff, R, L,
                                                frequencies=freqs,
                                                log_amplitudes=log_amps,
                                                log_mode_lifetimes=log_lifetimes)

test_freqs = np.logspace(-2, np.log10(freqs.max()), 1e6)
plt.loglog(test_freqs, 1e6/(2*np.pi) * kernel.get_psd(2*np.pi*test_freqs*1e-6))
plt.gca().set(xlabel='Frequency [$\mu$Hz]', ylabel='Power [ppm$^2$/$\mu$Hz]')
plt.show()